pub struct RuntimeOptions {Show 13 fields
singlepass: bool,
cranelift: bool,
llvm: bool,
experimental_artifact: bool,
enable_verifier: bool,
pub(crate) compiler_debug_dir: Option<PathBuf>,
profiler: Option<Profiler>,
_enable_pass_params_opt: bool,
compiler_threads: Option<NonZero<usize>>,
enable_nan_canonicalization: bool,
disable_non_volatile_memops: bool,
enable_experimental_unaligned_memory_accesses: bool,
features: WasmFeatures,
}Expand description
The compiler options
Fields
singlepass: boolUse Singlepass compiler.
cranelift: boolUse Cranelift compiler.
llvm: boolUse LLVM compiler.
experimental_artifact: boolUse the experimental artifact format.
enable_verifier: boolEnable compiler internal verification.
Available for Cranelift, LLVM and Singlepass.
compiler_debug_dir: Option<PathBuf>Debug directory, where IR and object files will be written to.
Available for Cranelift, LLVM and Singlepass.
profiler: Option<Profiler>Enable a profiler.
Available for Cranelift, LLVM and Singlepass.
_enable_pass_params_opt: boolDeprecated option as m0 optimization always play role if we use a static memory
compiler_threads: Option<NonZero<usize>>Sets the number of threads used to compile the input module(s).
enable_nan_canonicalization: boolEnable NaN canonicalization during compilation to produce deterministic canonical quiet NaNs (QNaNs) across architectures.
disable_non_volatile_memops: boolDisable LLVM non-volatile memory operations.
Available for LLVM.
enable_experimental_unaligned_memory_accesses: boolAllow unaligned memory accesses.
This feature is experimental and currently supports only Cranelift scalar types and Singlepass on RISC-V for integral types.
features: WasmFeaturesImplementations
Sourceimpl RuntimeOptions
impl RuntimeOptions
fn validate_profiler(&self) -> Result<()>
pub fn get_available_backends(&self) -> Result<Vec<BackendType>>
Sourcepub fn filter_backends_by_features(
backends: Vec<BackendType>,
required_features: &Features,
target: &Target,
) -> Vec<BackendType>
pub fn filter_backends_by_features( backends: Vec<BackendType>, required_features: &Features, target: &Target, ) -> Vec<BackendType>
Filter enabled backends based on required WebAssembly features
pub fn get_store(&self) -> Result<Store>
pub fn get_engine(&self, target: &Target) -> Result<Engine>
pub fn get_engine_for_module( &self, module_contents: &[u8], target: &Target, ) -> Result<Engine>
pub fn get_engine_for_features( &self, required_features: &Features, target: &Target, ) -> Result<Engine>
Sourcepub fn get_features(&self, default_features: &Features) -> Result<Features>
pub fn get_features(&self, default_features: &Features) -> Result<Features>
Get the enabled Wasm features.
Sourcepub fn get_configured_features(&self) -> Result<Features>
pub fn get_configured_features(&self) -> Result<Features>
Get a copy of the default features with user-configured options
Sourcepub fn detect_features_from_wasm(
&self,
wasm_bytes: &[u8],
) -> Result<Features, BinaryReaderError>
pub fn detect_features_from_wasm( &self, wasm_bytes: &[u8], ) -> Result<Features, BinaryReaderError>
Detect features from a WebAssembly module binary.
pub fn get_sys_compiler_engine_for_target( &self, target: Target, ) -> Result<Engine, Error>
pub(crate) fn get_sys_compiler_config( &self, rt: &BackendType, ) -> Result<Box<dyn CompilerConfig>>