select_volume_by_selector

Function select_volume_by_selector 

pub(crate) fn select_volume_by_selector<'a>(
    app_name: &str,
    volumes: &'a [Volume],
    selector: &str,
) -> Result<&'a Volume, Error>
Resolve a --volume selector to a single volume. The selector may be the friendly name, the mount path (exactly as shown by wasmer app volume list, e.g. /data), or the volume id.

The volume id is opaque and unique, so an exact id match is unambiguous and always wins: a volume can never be shadowed by another volume’s (user-chosen) name or mount path. If a volume’s name collides with a volume’s id, the id always wins.