pub struct CreateExe {
env: WasmerEnv,
path: PathBuf,
output: PathBuf,
debug_dir: Option<PathBuf>,
precompiled_atom: Vec<String>,
target_triple: Option<Triple>,
use_wasmer_release: Option<String>,
cpu_features: Vec<CpuFeature>,
libraries: Vec<String>,
cross_compile: CrossCompile,
compiler: RuntimeOptions,
}Expand description
The options for the wasmer create-exe subcommand
Fields
env: WasmerEnvpath: PathBufInput file
output: PathBufOutput file
debug_dir: Option<PathBuf>Optional directory used for debugging: if present, will output the zig command for reproducing issues in a debug directory.
precompiled_atom: Vec<String>Prefix for every input file, e.g. “wat2wasm:sha256abc123” would prefix every function in the wat2wasm input object with the “sha256abc123” hash
If only a single value is given without containing a “:”, this value is used for all input files. If no value is given, the prefix is always equal to the sha256 of the input .wasm file
target_triple: Option<Triple>Compilation Target triple
Accepted target triple values must follow the ‘target_lexicon’ crate format.
The recommended targets we try to support are:
- “x86_64-linux-gnu”
- “aarch64-linux-gnu”
- “arm64-apple-darwin”
- “x86_64-windows-gnu”
use_wasmer_release: Option<String>Can specify either a release version (such as “3.0.1”) or a URL to a tarball to use for linking. By default, create-exe will always pull the latest release tarball from GitHub, this flag can be used to override that behaviour.
cpu_features: Vec<CpuFeature>libraries: Vec<String>Additional libraries to link against. This is useful for fixing linker errors that may occur on some systems.
cross_compile: CrossCompilecompiler: RuntimeOptionsTrait Implementations
Sourceimpl Args for CreateExe
impl Args for CreateExe
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl CliCommand for CreateExe
impl CliCommand for CreateExe
Sourceimpl FromArgMatches for CreateExe
impl FromArgMatches for CreateExe
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for CreateExe
impl Parser for CreateExe
fn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>