pub struct Init {Show 13 fields
env: WasmerEnv,
pub lib: bool,
pub bin: bool,
pub empty: bool,
pub overwrite: bool,
pub quiet: bool,
pub namespace: Option<String>,
pub package_name: Option<String>,
pub version: Option<Version>,
pub manifest_path: Option<PathBuf>,
pub template: Option<Template>,
pub include: Vec<String>,
pub out: Option<PathBuf>,
}Expand description
CLI args for the wasmer init command
Fields
env: WasmerEnvlib: boolInitialize wasmer.toml for a library package
bin: boolInitialize wasmer.toml for a binary package
empty: boolInitialize an empty wasmer.toml
overwrite: boolForce overwriting the wasmer.toml, even if it already exists
quiet: boolDon’t display debug output
namespace: Option<String>Namespace to init with, default = current logged in user or _
package_name: Option<String>Package name to init with, default = Cargo.toml name or current directory name
version: Option<Version>Version of the initialized package
manifest_path: Option<PathBuf>If the manifest-path is a Cargo.toml, use that file to initialize the wasmer.toml
template: Option<Template>Add default dependencies for common packages
include: Vec<String>Include file paths into the target container filesystem
out: Option<PathBuf>Directory of the output file name. wasmer init will error if the target dir already contains a wasmer.toml. Also sets the package name.
Implementations
Sourceimpl Init
impl Init
Sourcefn write_wasmer_toml(path: &PathBuf, toml: &Manifest) -> Result<(), Error>
fn write_wasmer_toml(path: &PathBuf, toml: &Manifest) -> Result<(), Error>
Writes the metadata to a wasmer.toml file, making sure we include the
NOTE so people get a link to the registry docs.
fn target_file(&self) -> Result<(String, PathBuf), Error>
fn get_filesystem_mapping( include: &[String], ) -> impl Iterator<Item = (String, PathBuf)> + '_
fn get_command(modules: &[Module], bin_or_lib: BinOrLib) -> Vec<Command>
Sourcefn get_dependencies(template: Option<&Template>) -> IndexMap<String, VersionReq>
fn get_dependencies(template: Option<&Template>) -> IndexMap<String, VersionReq>
Returns the dependencies based on the --template flag
fn get_bin_or_lib(&self) -> Result<BinOrLib, Error>
Sourcefn get_bindings(
target_file: &Path,
bin_or_lib: BinOrLib,
) -> Option<GetBindingsResult>
fn get_bindings( target_file: &Path, bin_or_lib: BinOrLib, ) -> Option<GetBindingsResult>
Get bindings returns the first .wai / .wit file found and optionally takes a warning callback that is triggered when > 1 .wai files are found