pub struct PackageDownload {
pub env: WasmerEnv,
validate: bool,
out_path: Option<PathBuf>,
quiet: bool,
unpack: bool,
package: PackageSource,
}Expand description
Download a package from the registry.
Examples:
-
wasmer package download wasmer/helloDownload thewasmer/hellopackage, writing to./hello@<version>.webc. -
wasmer package download --unpack wasmer/hello@0.1.0 -o hello.webcDownload thewasmer/hellopackage version0.1.0, writing to./hello.webc, and unpacking it to./hello.webc.unpacked/.
Fields
env: WasmerEnvvalidate: boolVerify that the downloaded file is a valid package.
out_path: Option<PathBuf>Path where the package file should be written to. If not specified, the data will be written to stdout.
quiet: boolRun the download command without any output
unpack: boolUnpack the downloaded package.
The unpacked directory will be next to the downloaded file, with a .unpacked suffix.
Note: unpacking can also be done manually with the wasmer package unpack command.
package: PackageSourceThe package to download.
Implementations