sort_versions

Function sort_versions 

fn sort_versions(versions: &mut [String])
Sort version strings ascending, parsing them as semver where possible and falling back to lexical order for anything that doesn’t parse.