pub struct PackageSearch {Show 23 fields
fmt: ListFormatOpts,
env: WasmerEnv,
owner: Option<String>,
published_by: Option<String>,
curated: Option<bool>,
deployable: Option<bool>,
has_bindings: bool,
has_commands: bool,
standalone: bool,
interfaces: Vec<String>,
license: Option<String>,
min_downloads: Option<i32>,
min_likes: Option<i32>,
min_size: Option<i32>,
created_after: Option<DateTime>,
created_before: Option<DateTime>,
published_after: Option<DateTime>,
published_before: Option<DateTime>,
published_within: Option<PublishedWithin>,
order_by: OrderBy,
sort: Sort,
max: usize,
query: String,
}Expand description
Search for packages in the registry.
Fields
fmt: ListFormatOptsenv: WasmerEnvowner: Option<String>Only show packages owned by this user or namespace.
published_by: Option<String>Only show packages published by this user.
curated: Option<bool>Filter by curated status. --curated for curated only, --curated=false
for non-curated.
deployable: Option<bool>Filter by deployable status. --deployable for deployable only,
--deployable=false for non-deployable.
has_bindings: boolOnly show packages whose latest version has bindings.
has_commands: boolOnly show packages whose latest version has commands.
standalone: boolOnly show standalone packages (implies –has-commands).
interfaces: Vec<String>Only show packages exposing this interface (repeatable).
license: Option<String>Only show packages whose latest version’s license matches (substring).
min_downloads: Option<i32>Only show packages with at least this many downloads.
min_likes: Option<i32>Only show packages with at least this many likes.
min_size: Option<i32>Only show packages whose latest version is at least this many bytes.
created_after: Option<DateTime>Only show packages created on or after this RFC3339 timestamp (e.g. 2024-01-01T00:00:00Z).
created_before: Option<DateTime>Only show packages created on or before this RFC3339 timestamp.
published_after: Option<DateTime>Only show packages last published on or after this RFC3339 timestamp.
published_before: Option<DateTime>Only show packages last published on or before this RFC3339 timestamp.
published_within: Option<PublishedWithin>Only show packages published within the given window.
order_by: OrderByField to order results by.
sort: SortSort direction.
max: usizeMaximum number of results to display.
query: StringThe search query. Leave empty to list all (matching) packages.