utf8_env_part

Function utf8_env_part 

fn utf8_env_part(part: OsString) -> Result<String>
Environment variables are arbitrary byte strings on unix, but Wasi stores them as String, so reject the ones that cannot be represented.