async fn version_not_found_error(
client: &WasmerClient,
full_name: &str,
requested: Option<&str>,
) -> ErrorExpand description
Build a helpful error for when get_package_version returns nothing.
If the package exists but the requested version doesn’t, the error lists the versions that are available; otherwise it reports the package as not found.